@@ -1,7 +1,7 @@
-from flask import render_template, Blueprint, Markup, url_for
-
 import os.path
 
+from flask import render_template, Blueprint, Markup, url_for
+
 import qrcode as qrc
 
 def qrcode(data, filename='QRcode', filedir='.', version=None, error_correction=qrc.constants.ERROR_CORRECT_L, box_size=10, border=0, fit=True):
@@ -17,11 +17,11 @@ def qrcode(data, filename='QRcode', filedir='.', version=None, error_correction=
     qrpath = url_for('static', filename=os.path.join(filedir, filename) + '.png' )
 
     try:
-        with open('./' + qrpath, 'wb') as qrfile:
+        with open('.' + qrpath, 'wb') as qrfile:
             qrimg = qr.make_image()
             qrimg.save(qrfile)
     except IOError as err:
-        print("Error: %s" % err )
+        raise err("Could not create QR code file")
 
     return Markup(render_template('qrcode/qrcode.html', qrcode_url=qrpath))
 
